==> testops-api-1.0.1.tar.gz: testops-api-1.0.1/docs/TestObjectApi.md <==
# testops_api.TestObjectApi

All URIs are relative to *https://testops.katalon.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get1**](TestObjectApi.md#get1) | **GET** /api/v1/test-object-entities/{id} | Returns a Test Object detail.


# **get1**
> TestObjectEntityResource get1(id)

Returns a Test Object detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_object_api
from testops_api.model.test_object_entity_resource import TestObjectEntityResource
from pprint import pprint
# Defining the host is optional and defaults to https://testops.katalon.io
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "https://testops.katalon.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_object_api.TestObjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Returns a Test Object detail.
        api_response = api_instance.get1(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestObjectApi->get1: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

[**TestObjectEntityResource**](TestObjectEntityResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> testops-api-1.0.2.tar.gz: testops-api-1.0.2/docs/TestObjectApi.md <==
# testops_api.TestObjectApi

All URIs are relative to *http://localhost:8443*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get5**](TestObjectApi.md#get5) | **GET** /api/v1/test-object-entities/{id} | Returns a Test Object detail.


# **get5**
> TestObjectEntityResource get5(id)

Returns a Test Object detail.

### Example

* Basic Authentication (basicScheme):
```python
import time
import testops_api
from testops_api.api import test_object_api
from testops_api.model.test_object_entity_resource import TestObjectEntityResource
from pprint import pprint
# Defining the host is optional and defaults to http://localhost:8443
# See configuration.py for a list of all supported configuration parameters.
configuration = testops_api.Configuration(
    host = "http://localhost:8443"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicScheme
configuration = testops_api.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Enter a context with an instance of the API client
with testops_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = test_object_api.TestObjectApi(api_client)
    id = 1 # int | 

    # example passing only required values which don't have defaults set
    try:
        # Returns a Test Object detail.
        api_response = api_instance.get5(id)
        pprint(api_response)
    except testops_api.ApiException as e:
        print("Exception when calling TestObjectApi->get5: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  |

### Return type

[**TestObjectEntityResource**](TestObjectEntityResource.md)

### Authorization

[basicScheme](../README.md#basicScheme)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
